@@ -1,12 +1,12 @@
 ﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
- * @file		iutest_ver.hpp
- * @brief		iris unit test version 定義 ファイル
+ * @file        iutest_ver.hpp
+ * @brief       iris unit test version
  *
- * @author		t.shirayanagi
- * @par			copyright
- * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
+ * @author      t.shirayanagi
+ * @par         copyright
+ * Copyright (C) 2011-2016, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -17,24 +17,24 @@
 
 //======================================================================
 // define
-#define IUTEST_VER			0x01140000u //!< iutest version 1.14.0.0
-#define IUTEST_MAJORVER		0x01u		//!< Major Version
-#define IUTEST_MINORVER		0x14u		//!< Minor Version
-#define IUTEST_BUILD		0x00u		//!< Build
-#define IUTEST_REVISION		0x00u		//!< Revision
+#define IUTEST_VER          0x01150200u //!< iutest version 1.15.2.0
+#define IUTEST_MAJORVER     0x01u       //!< Major Version
+#define IUTEST_MINORVER     0x15u       //!< Minor Version
+#define IUTEST_BUILD        0x02u       //!< Build
+#define IUTEST_REVISION     0x00u       //!< Revision
 
 /**
  * @mainpage
- * @sa	@b	ProjectHome \n
- *			OSDN        : http://osdn.jp/projects/iutest/ \n
- *			github		: https://github.com/srz-zumix/iutest \n
- *			google group: https://groups.google.com/forum/?fromgroups#!forum/g-iutest \n
+ * @sa  @b  ProjectHome \n
+ *          OSDN        : http://osdn.jp/projects/iutest/ \n
+ *          github      : https://github.com/srz-zumix/iutest \n
+ *          google group: https://groups.google.com/forum/?fromgroups#!forum/g-iutest \n
  *
- * @par		copyright
- * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
+ * @par     copyright
+ * Copyright (C) 2011-2016, Takazumi Shirayanagi\n
  * This software is released under the new BSD License.
  *
- * @par		LICENSE
+ * @par     LICENSE
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:\n
@@ -63,8 +63,8 @@
 */
 
 /**
- * @page	CMDLINE		コマンドラインオプション
- * @par		Command Line Options
+ * @page    CMDLINE     コマンドラインオプション
+ * @par     Command Line Options
  <table>
    <tr><td>--help, -h                        </td><td></td><td>Generate help message.</td></tr>
    <tr><td>--iutest_output                   </td><td>xml|junit[:path]</td><td>Path of xml report.</td></tr>
@@ -80,7 +80,7 @@
    <tr><td>--iutest_throw_on_failure         </td><td>[yes|no]</td><td>When that failed to throw.</td></tr>
    <tr><td>--iutest_catch_exceptions         </td><td>&lt;yes|no&gt;</td><td>Catch exceptions enable.</td></tr>
    <tr><td>--iutest_print_time               </td><td>&lt;yes|no&gt;</td><td>Setting the display of elapsed time.</td></tr>
-   <tr><td>--iutest_repeat                   </td><td>&lt;count&gt;</td><td>Set the number of repetitions of the test.</td></tr>
+   <tr><td>--iutest_repeat                   </td><td>&lt;count&gt;</td><td>Set the number of repetitions of the test. use a negative count to repeat forever.</td></tr>
    <tr><td>--iutest_stream_result_to         </td><td>&lt;host:port&gt;</td><td>Set stream test results server.</td></tr>
    <tr><td>--iutest_file_location            </td><td>&lt;auto|vs|gcc&gt;</td><td>Format file location messages.</td></tr>
    <tr><td>--iutest_default_package_name     </td><td>[name]</td><td>Set default root package name.</td></tr>
@@ -92,8 +92,8 @@
 */
 
 /**
- * @page	ENVIRONMENT_OPTIONS	環境変数オプション
- * @par		Environment variable Options
+ * @page    ENVIRONMENT_OPTIONS 環境変数オプション
+ * @par     Environment variable Options
  <table>
    <tr><td>IUTEST_OUTPUT=xml|junit[:path]  </td><td>Path of xml report.</td></tr>
    <tr><td>IUTEST_COLOR=yes|no|auto        </td><td>Console color enable.</td></tr>
@@ -113,9 +113,42 @@
 */
 
 /**
- * @page	CHANGELOG	変更履歴
- * @par		Changes
+ * @page    CHANGELOG   変更履歴
+ * @par     Changes
  <ul>
+  <li>v1.15.2.0
+    <ul>
+      <li>IUTEST_TYPED_TEST_P に対して friend できるように IUTEST_FRIEND_TYPED_TEST_P_DECLARATION/IUTEST_FRIEND_TYPED_TEST_P を追加</li>
+      <li>iuwandbox に --sprout/--msgpack オプションを追加</li>
+      <li>iuwandbox の --list_compiler オプションでバージョンを出力しないように変更。--verbose を付けると以前と同じバージョン付きの出力をする</li>
+      <li>iuwandbox で --expand_include オプションを付けなかった場合の include されたファイルの対応を修正</li>
+      <li>iuwandbox の --boost オプションが Python3 で使えない問題を修正</li>
+      <li>iuwandbox で未定義オプションを指定した場合にエラーにならない問題を修正</li>
+      <li>IUTEST(A, B_C) と IUTEST(A_B, C) が名前の衝突でコンパイルエラーになる問題を修正</li>
+      <li>色付きコンソールの自動判定を修正</li>
+      <li>deprecated: IUTEST_HAS_STRSTREAM は将来的に削除されます</li>
+      <li>deprecated: IUTEST_HAS_ARITHMETIC_EXPRESSION_DECOMPOSE は将来的に削除されます</li>
+    </ul>
+  </li>
+  <li>v1.15.1.0
+    <ul>
+      <li>stderr に xml の内容を出力するリスナーを追加</li>
+      <li>iuwandbox に xml 出力オプション(--xml, --junit)を追加</li>
+      <li>--help|spec|feature|version を同時に使用可能に変更 (e.g. --spec --feature)</li>
+      <li>CSV パラメータのパス解決処理を修正</li>
+      <li>fused-src 生成ツールを修正</li>
+    </ul>
+  </li>
+  <li>v1.15.0.0
+    <ul>
+      <li>--iutest_output オプションで repeat 回数のフォーマットに対応 e.g. --iutest_output=xml:test_%d.xml</li>
+      <li>CSV ファイルから値のパラメータ作成に対応</li>
+      <li>IUTEST_ALIAS_TESTNAME_F,IUTEST_JAPANESE_NAME_F の引数の順番を変更</li>
+      <li>値のパラメータ化テストのテスト名指定方法を変更</li>
+      <li>値のパラメータ化テストのテスト名指定方法の Google Test 互換対応</li>
+      <li>IUTEST_TYPED_TEST_APPEND_TYPENAME を IUTEST_HAS_TYPED_TEST_APPEND_TYPENAME に変更</li>
+    </ul>
+  </li>
   <li>v1.14.0.0
     <ul>
       <li>::iutest::Range を Enum に対応</li>
